@@ -1209,10 +1209,10 @@ class VariableClProfileData(ReadonlyTableVariable):
 
     def get(self, hr=HumanReadable.No):
         try:
-            self.Get('cl_update_profile_url')
+            self.Get(f'cl_{self.section}_profile_url')
         except:
             return [[]]
-        if self.Get('cl_update_profile_url'):
+        if self.Get(f'cl_{self.section}_profile_url'):
             rep = self.Get(self.repository)
             if not rep:
                 return [[]]
@@ -1222,7 +1222,9 @@ class VariableClProfileData(ReadonlyTableVariable):
             repo_name = profiles[0].repository.repo_name
         else:
             full_path = self.Get('cl_profile_system')
-            storage_path = self.Get('cl_update_repos_storage')
+            storage_path = self.Get('update.cl_update_repos_storage')
+            if self.section == 'builder':
+                full_path = pathJoin('/', self.Get('cl_builder_path'), full_path)
             if storage_path in full_path:
                 repo_name = full_path.split(storage_path)[1].replace('/', ' ').split()[0]
                 profiles_desc = path.join(storage_path, repo_name, "profiles/profiles.desc")
